//******************************************************************************
// In this example the nRF24L01 is sending the Switches info.
// By either pressing SW1 or SW2, on the receiving board the buzzer is turned ON.
// On the TX board, by pressing SW1, LED1 is turned ON, 
// while pressing SW2 LED2 is turned ON.
//
// Tested Platform: mini Sensing Board
// Tested MCU: PIC32MX220F128D
// Tested Compiler: XC32 2.50
//******************************************************************************

#include <xc.h>

#define SYSTEM_CLOCK 32000000UL

#include "LTlib.h"

#include "LTlib_utilities.h"
#include "LTlib_utilities.c"

#include "HW_mini_Sensing_PIC_Board.h"

#include "module_IO.h"
#include "module_IO.c"

#include "LTlib_delay.h"
#include "LTlib_delay.c"

#include "module_SPI.h"
#include "module_SPI.c"

#define NRF24L01_SPI_MODULE_1 
#include "nRF24L01.h"
#include "nRF24L01.c"

#define ADDRESS_SIZE NRF24L01_ADDRESS_5_BYTES
#define PAYLOAD_SIZE 20
#define TX_CHANNEL 10

#define TIME_ON 500u
#define TIME_BLINK 500u
#define BEEP_COUNT 256u

void main (void) {
    
    uint16_t counter = 0x00;
    NRF24L01_packet packet;
    
    uint8_t address[NRF24L01_ADDRESS_MAX_SIZE];

    IO_set_all_ports_as_inputs();

    //Red LED1 on the board
    P6_DIR = SET_AS_OUTPUT;
    
    //Red LED2 on the board
    P12_DIR = SET_AS_OUTPUT;
    
    //SW1 on the board
    P4_DIR = SET_AS_INPUT;
    
    //SW2 on the board
    P3_DIR = SET_AS_INPUT;
    
    //Output Buzzer
    BUZZER_DIR = SET_AS_OUTPUT;
    
    //LED state settings
    P6_OUT = ON_STATE;
    P12_OUT = ON_STATE;
    delay_ms (100);
    P6_OUT = OFF_STATE;
    P12_OUT = OFF_STATE;
    delay_ms (100);
    P6_OUT = ON_STATE;
    P12_OUT = ON_STATE;
    delay_ms (100);
    P6_OUT = OFF_STATE;
    P12_OUT = OFF_STATE;
    
    //************************************
    // Buzzer Test
    //************************************
    for (counter = 0; counter <BEEP_COUNT; counter++ ){
        delay_us (240);
        BUZZER_OUT = (BUZZER_OUT^0x01);  
    }

    NRF24L01_initialize (TX_CHANNEL, NRF24L01_RF_POWER_0dBm, NRF24L01_BIT_RATE_1MHZ);
       
    NRF24L01_packet_format (NRF24L01_ADDRESS_5_BYTES, NRF24L01_CRC_ENABLED, NRF24L01_CRC_SIZE_1_BYTE);
       
    address[0] = 0x01;
    address[1] = 0x02;
    address[2] = 0x03;  
    address[3] = 0x04; 
    address[4] = 0x05;    
    NRF24L01_set_address (NRF24L01_ADDRESS_TX, address, ADDRESS_SIZE);
    
    //Set Pipe P0 address as the TX address
    NRF24L01_set_address (NRF24L01_ADDRESS_RX_P0, address, ADDRESS_SIZE);
    NRF24L01_set_pipe (NRF24L01_P0_SIZE, PAYLOAD_SIZE);
    NRF24L01_pipe_configuration (NRF24L01_PIPE_0_EN, NRF24L01_PIPE_ENABLED);  
     
    while (1){
        
        packet.size = PAYLOAD_SIZE;
       
        //**********************************************************************
        //Check if any data has been received
        //**********************************************************************        
        //Turn on the RX mode
        NRF24L01_set_RX_mode (NRF24L01_RX_MODE_ON);
        delay_ms (1);
        
        
        if (NRF24L01_is_data_received() != NRF24L01_PIPES_EMPTY){
                        
            packet.size = PAYLOAD_SIZE;        
            NRF24L01_read_data (&packet);
                        
            if (packet.payload[0] == 0x03){
                for (counter = 0; counter <BEEP_COUNT; counter++ ){
                    delay_us (240);
                    BUZZER_OUT = (BUZZER_OUT^0x01);  
                }
            }
            
        } else {
            
        }
        
        
        //**********************************************************************
        //Check if any button has been pressed
        //**********************************************************************
        if (P4_IN == BUTTON_PRESSED){
            delay_ms (10);
            
            if (P4_IN == BUTTON_PRESSED){
                
                packet.payload[0] = 0x03;
                
                NRF24L01_send_data (packet);
               
                P6_OUT = ON_STATE;
                delay_ms (5);
                P6_OUT = OFF_STATE;  
            }            
        }
        
        
        if (P3_IN == BUTTON_PRESSED){
            delay_ms (10);
            
            if (P3_IN == BUTTON_PRESSED){
                
                packet.payload[0] = 0x03;
                
                NRF24L01_send_data (packet);
               
                P12_OUT = ON_STATE;
                delay_ms (5);
                P12_OUT = OFF_STATE;  
            }            
        }        
    }
}


